@@ -14,7 +14,6 @@
 #include <QInputDialog>
 #include <QPointer>
 
-#include <kwidgetsaddons_version.h>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KScoreDialog>
@@ -114,7 +113,7 @@ void PlayField::newGame()
     endGame();
     delete m_menu;
     
-    Kg::difficulty()->setGameRunning(false);
+    KGameDifficulty::global()->setGameRunning(false);
     
     m_chat->hide();
     m_seaView->screen(Sea::Player(0))->show();
@@ -145,7 +144,7 @@ void PlayField::highscores()
             KScoreDialog::Custom2 | 
             KScoreDialog::Custom3, 
             this);
-    highscoredialog->initFromDifficulty(Kg::difficulty());
+    highscoredialog->initFromDifficulty(KGameDifficulty::global());
     highscoredialog->addField(KScoreDialog::Custom1, i18n("Shots"), QStringLiteral("shots"));
     highscoredialog->addField(KScoreDialog::Custom2, i18n("Hits"), QStringLiteral("hits"));
     highscoredialog->addField(KScoreDialog::Custom3, i18n("Misses"), QStringLiteral("water"));
@@ -165,7 +164,7 @@ void PlayField::gameOver(Sea::Player winner)
                     KScoreDialog::Custom2 | 
                     KScoreDialog::Custom3, 
                     this);
-            highscoredialog->initFromDifficulty(Kg::difficulty());
+            highscoredialog->initFromDifficulty(KGameDifficulty::global());
             highscoredialog->addField(KScoreDialog::Custom1, i18n("Shots"), QStringLiteral("shots"));
             highscoredialog->addField(KScoreDialog::Custom2, i18n("Hits"), QStringLiteral("hits"));
             highscoredialog->addField(KScoreDialog::Custom3, i18n("Misses"), QStringLiteral("water"));
@@ -234,20 +233,12 @@ void PlayField::toggleMultiple(bool enable)
 
 void PlayField::restartRequested()
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int ans = KMessageBox::questionTwoActions(this,
-#else
-    int ans = KMessageBox::questionYesNo(this,
-#endif
                                          i18n("Restart game"),
                                          i18n("Your opponent has requested to restart the game. Do you accept?"),
                                          KGuiItem(i18nc("@action:button", "Accept"), QStringLiteral("dialog-ok")),
                                          KGuiItem(i18nc("@action:button", "Reject"), QStringLiteral("dialog-cancel")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (ans == KMessageBox::PrimaryAction) {
-#else
-    if (ans == KMessageBox::Yes) {
-#endif
         restart();
     }
 }
@@ -295,7 +286,7 @@ void PlayField::playerReady(int player)
 void PlayField::startGame()
 {
     //the game has a fixed difficulty level only if there is an AI
-    Kg::difficulty()->setGameRunning(m_controller->hasAI());
+    KGameDifficulty::global()->setGameRunning(m_controller->hasAI());
     startPlacingShips();
     Q_EMIT placeShips();
 }
@@ -311,17 +302,9 @@ void PlayField::restartPlacingShips(Sea::Player player)
     m_status_bar->showMessage(i18n("You can't place your remaining ships."));
     KGuiItem buttonRestart(i18nc("@action", "Restart"), QStringLiteral("view-refresh"));
     KGuiItem buttonAbort(i18nc("@action", "Abort"), QStringLiteral("dialog-cancel"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int res=KMessageBox::warningTwoActions(this,
-#else
-    int res=KMessageBox::warningYesNo(this,
-#endif
                                       i18n("You can't place your remaining ships. Please restart placing ships or abort game"), i18n("Restart placing ships"), buttonRestart, buttonAbort);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (res == KMessageBox::PrimaryAction) {
-#else
-    if (res == KMessageBox::Yes) {
-#endif
         startPlacingShips();
         m_controller->notifyRestartPlacingShips(player);
     }
